@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,12 +30,7 @@ namespace KeePass.App.Configuration
 		{
 		}
 
-		private bool m_bEnabled = false;
 		[DefaultValue(false)]
-		public bool Enabled
-		{
-			get { return m_bEnabled; }
-			set { m_bEnabled = value; }
-		}
+		public bool Enabled { get; set; }
 	}
 }
