@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -210,8 +210,8 @@ namespace KeePass.App.Configuration
 			{
 				if(!File.Exists(g_strEnforcedConfigFile)) return null;
 
-				XmlDocument xd = XmlUtilEx.CreateXmlDocument();
-				xd.Load(g_strEnforcedConfigFile);
+				XmlDocument xd = XmlUtilEx.LoadXmlDocument(g_strEnforcedConfigFile,
+					StrUtil.Utf8);
 
 				if(bSetPrimary) g_xdEnforced = xd;
 				return xd;
@@ -251,8 +251,7 @@ namespace KeePass.App.Configuration
 				}
 				else // Enforced configuration
 				{
-					XmlDocument xd = XmlUtilEx.CreateXmlDocument();
-					xd.Load(strFilePath);
+					XmlDocument xd = XmlUtilEx.LoadXmlDocument(strFilePath, StrUtil.Utf8);
 
 					XmContext ctx = new XmContext(xd, AppConfigEx.GetNodeOptions,
 						AppConfigEx.GetNodeKey);
