@@ -20,6 +20,7 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
+using System.Linq;
 using System.Text;
 
 using KeePassLib.Cryptography.PasswordGenerator;
@@ -141,11 +142,7 @@ namespace KeePassLib.Cryptography
 				m_uCharWeight = uCharWeight;
 				m_uOccExclThreshold = uOccExclThreshold;
 
-#if DEBUG
-				Dictionary<char, bool> d = new Dictionary<char, bool>();
-				foreach(char ch in m_strAlph) { d[ch] = true; }
-				Debug.Assert(d.Count == m_strAlph.Length); // No duplicates
-#endif
+				Debug.Assert(m_strAlph.Distinct().Count() == m_strAlph.Length);
 			}
 
 			public void Reset()
@@ -719,16 +716,10 @@ namespace KeePassLib.Cryptography
 			if(nZeros < strNumber.Length)
 			{
 				string strNonZero = strNumber.Substring(nZeros);
-
-#if KeePassLibSD
-				try { dblCost += Log2(double.Parse(strNonZero)); }
-				catch(Exception) { Debug.Assert(false); return; }
-#else
 				double d;
-				if(double.TryParse(strNonZero, out d))
+				if(StrUtil.TryParseDoubleInvariant(strNonZero, out d))
 					dblCost += Log2(d);
 				else { Debug.Assert(false); return; }
-#endif
 			}
 
 			vPatterns[i].Add(new QePatternInstance(i, strNumber.Length,
