@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,18 +69,18 @@ namespace KeePass.DataExchange
 		{
 			List<FileFormatProvider> l = m_lFormats;
 
-			l.Add(new KeePassCsv1x());
-			l.Add(new KeePassKdb1x());
-			l.Add(new KeePassKdb2x());
-			l.Add(new KeePassKdb2xRepair());
-			l.Add(new KeePassKdb2x3());
-			l.Add(new KeePassXml1x());
-			l.Add(new KeePassXml2x());
+			l.Add(new KeePassCsv1());
+			l.Add(new KeePassKdb1());
+			l.Add(new KeePassKdbx2());
+			l.Add(new KeePassKdbx2Repair());
+			l.Add(new KeePassKdbx2v3());
+			l.Add(new KeePassXml1());
+			l.Add(new KeePassXml2());
 
 			l.Add(new GenericCsv());
 
-			l.Add(new KeePassHtml2x());
-			l.Add(new XslTransform2x());
+			l.Add(new KeePassHtml2());
+			l.Add(new XslTransform2());
 			l.Add(new WinFavorites10(false));
 			l.Add(new WinFavorites10(true));
 
@@ -138,10 +138,9 @@ namespace KeePass.DataExchange
 			l.Add(new ChromeCsv66());
 			l.Add(new MozillaBookmarksHtml100());
 			l.Add(new MozillaBookmarksJson100());
+			l.Add(new FirefoxCsv143());
 			l.Add(new PwExporterXml105());
 
-			l.Add(new Spamex20070328());
-
 #if DEBUG
 			// Ensure name uniqueness
 			for(int i = 0; i < l.Count; ++i)
