@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,10 +19,9 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.IO;
-using System.Drawing;
 using System.Diagnostics;
+using System.IO;
+using System.Text;
 
 using KeePass.Resources;
 
@@ -39,10 +38,5 @@ namespace KeePass.DataExchange.Formats
 	internal sealed class KasperskyPwMgrXml50 : StickyPwXml50
 	{
 		public override string FormatName { get { return "Kaspersky Password Manager XML"; } }
-
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_KasperskyPwMgr; }
-		}
 	}
 }
