@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 using System;
 using System.Collections.Generic;
-using System.Drawing;
 using System.IO;
 using System.Text;
 using System.Xml;
@@ -29,7 +28,6 @@ using KeePass.Resources;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
-using KeePassLib.Security;
 using KeePassLib.Utility;
 
 namespace KeePass.DataExchange.Formats
@@ -44,20 +42,15 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "xml"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_PwMem2008; }
-		}
-
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
 			string str = Preprocess(sInput);
 
-			PwMem2008XmlFile_Priv f = null;
+			PwMemory2008XmlFile_Priv f = null;
 			using(MemoryStream ms = new MemoryStream(StrUtil.Utf8.GetBytes(str), false))
 			{
-				f = XmlUtilEx.Deserialize<PwMem2008XmlFile_Priv>(ms);
+				f = XmlUtilEx.Deserialize<PwMemory2008XmlFile_Priv>(ms);
 			}
 			if((f == null) || (f.Cells == null)) return;
 
@@ -72,13 +65,13 @@ namespace KeePass.DataExchange.Formats
 
 				string strGroup = vCells[4];
 				PwGroup pg;
-				if(strGroup == ".") pg = pwStorage.RootGroup;
+				if(strGroup == ".") pg = pdStorage.RootGroup;
 				else if(vGroups.ContainsKey(strGroup)) pg = vGroups[strGroup];
 				else
 				{
 					pg = new PwGroup(true, true);
 					pg.Name = strGroup;
-					pwStorage.RootGroup.AddGroup(pg, true);
+					pdStorage.RootGroup.AddGroup(pg, true);
 
 					vGroups[strGroup] = pg;
 				}
@@ -87,22 +80,17 @@ namespace KeePass.DataExchange.Formats
 				pg.AddEntry(pe, true);
 
 				if(vCells[1] != ".")
-					pe.Strings.Set(PwDefs.TitleField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectTitle, vCells[1]));
+					ImportUtil.Add(pe, PwDefs.TitleField, vCells[1], pdStorage);
 				if(vCells[2] != ".")
-					pe.Strings.Set(PwDefs.UserNameField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectUserName, vCells[2]));
+					ImportUtil.Add(pe, PwDefs.UserNameField, vCells[2], pdStorage);
 				if(vCells[3] != ".")
-					pe.Strings.Set(PwDefs.PasswordField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectPassword, vCells[3]));
+					ImportUtil.Add(pe, PwDefs.PasswordField, vCells[3], pdStorage);
 			}
 		}
 
 		private static string Preprocess(Stream sInput)
 		{
-			StreamReader sr = new StreamReader(sInput, Encoding.UTF8);
-			string str = sr.ReadToEnd();
-			sr.Close();
+			string str = MemUtil.ReadString(sInput, Encoding.UTF8);
 
 			const string strStartTag = "<IMAGE";
 			const string strEndTag = "</IMAGE>";
@@ -122,7 +110,7 @@ namespace KeePass.DataExchange.Formats
 	}
 
 	[XmlRoot("CACHE")]
-	public sealed class PwMem2008XmlFile_Priv
+	public sealed class PwMemory2008XmlFile_Priv
 	{
 		[XmlElement("TITLE")]
 		public string Title { get; set; }
