@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@ using KeePass.Resources;
 using KeePassLib;
 using KeePassLib.Interfaces;
 using KeePassLib.Utility;
-using KeePassLib.Security;
 
 namespace KeePass.DataExchange.Formats
 {
@@ -42,12 +41,10 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "txt"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			StreamReader sr = new StreamReader(sInput, Encoding.Default, true);
-			string strData = sr.ReadToEnd();
-			sr.Close();
+			string strData = MemUtil.ReadString(sInput, Encoding.Default);
 
 			strData = StrUtil.NormalizeNewLines(strData, false);
 
@@ -61,7 +58,7 @@ namespace KeePass.DataExchange.Formats
 			List<string> lData = StrUtil.SplitWithSep(strData, vSeps, true);
 			Debug.Assert((lData.Count & 1) == 1);
 
-			PwGroup pgRoot = pwStorage.RootGroup;
+			PwGroup pgRoot = pdStorage.RootGroup;
 
 			PwGroup pgTemplates = new PwGroup(true, true, "Vorlagen",
 				PwIcon.MarkedDirectory);
@@ -74,11 +71,11 @@ namespace KeePass.DataExchange.Formats
 
 				if(strInit == strInitGroup) { }
 				else if(strInit == strInitTemplate)
-					ImportEntry(strPart, pgTemplates, pwStorage, false);
+					ImportEntry(strPart, pgTemplates, pdStorage, false);
 				else if(strInit == strInitEntry)
-					ImportEntry(strPart, pgRoot, pwStorage, false);
+					ImportEntry(strPart, pgRoot, pdStorage, false);
 				else if(strInit == strInitNote)
-					ImportEntry(strPart, pgRoot, pwStorage, true);
+					ImportEntry(strPart, pgRoot, pdStorage, true);
 				else { Debug.Assert(false); }
 			}
 		}
@@ -92,7 +89,7 @@ namespace KeePass.DataExchange.Formats
 			string[] v = strData.Split('\n');
 
 			if(v.Length == 0) { Debug.Assert(false); return; }
-			ImportUtil.AppendToField(pe, PwDefs.TitleField, v[0].Trim(), pd);
+			ImportUtil.Add(pe, PwDefs.TitleField, v[0].Trim(), pd);
 
 			int n = v.Length;
 			for(int j = n - 1; j >= 0; --j)
@@ -115,17 +112,16 @@ namespace KeePass.DataExchange.Formats
 						ImportUtil.AppendToField(pe, PwDefs.NotesField,
 							MessageService.NewLine, pd, string.Empty, false);
 					else
-						ImportUtil.AppendToField(pe, PwDefs.NotesField, str, pd);
+						ImportUtil.Add(pe, PwDefs.NotesField, str, pd);
 				}
 				else
 				{
-					string strRawKey = str.Substring(0, iSep);
+					string strKey = str.Substring(0, iSep);
 					string strValue = str.Substring(iSep + 1).Trim();
 
-					string strKey = ImportUtil.MapNameToStandardField(strRawKey, false);
-					if(string.IsNullOrEmpty(strKey)) strKey = strRawKey;
+					strKey = ImportUtil.MapName(strKey, false);
 
-					ImportUtil.AppendToField(pe, strKey, strValue, pd);
+					ImportUtil.Add(pe, strKey, strValue, pd);
 				}
 			}
 		}
