@@ -28,6 +28,7 @@ using System.Windows.Forms;
 
 using KeePass.App;
 using KeePass.DataExchange;
+using KeePass.DataExchange.Formats;
 using KeePass.Resources;
 using KeePass.UI;
 using KeePass.Util;
@@ -152,6 +153,8 @@ namespace KeePass.Forms
 
 			m_lvFields.Columns.Add(KPRes.Field);
 
+			m_lvFields.ItemDeleteButton = m_btnFieldDel;
+
 			AddCsvField(CsvFieldType.Title, null, null);
 			AddCsvField(CsvFieldType.UserName, null, null);
 			AddCsvField(CsvFieldType.Password, null, null);
@@ -406,6 +409,7 @@ namespace KeePass.Forms
 				m_lvFields.Items.RemoveAt(lvsic[i]);
 
 			EnableControlsEx();
+			UIUtil.SetFocus(m_lvFields, this);
 		}
 
 		private void OnFieldsSelectedIndexChanged(object sender, EventArgs e)
@@ -472,10 +476,9 @@ namespace KeePass.Forms
 			string strName = (bName ? m_tbFieldName.Text : null);
 			string strFormat = (bFormat ? m_cmbFieldFormat.Text : null);
 
+			UIUtil.DeselectAllItems(m_lvFields);
 			AddCsvField(t, strName, strFormat);
 			ProcessResize();
-			for(int i = 0; i < (m_lvFields.Items.Count - 1); ++i)
-				m_lvFields.Items[i].Selected = false;
 			m_lvFields.EnsureVisible(m_lvFields.Items.Count - 1);
 			UIUtil.SetFocusedItem(m_lvFields, m_lvFields.Items[
 				m_lvFields.Items.Count - 1], true);
@@ -550,7 +553,7 @@ namespace KeePass.Forms
 			if(bCreatePreview) m_lvImportPreview.BeginUpdate();
 
 			DateTime dtNow = DateTime.UtcNow;
-			DateTime dtNoExpire = KdbTime.NeverExpireTime.ToDateTime();
+			DateTime dtNeverExpires = (new KeePassKdb1()).NeverExpiresTime;
 			bool bIgnoreFirstRow = m_cbIgnoreFirst.Checked;
 			bool bIsFirstRow = true;
 			bool bMergeGroups = m_cbMergeGroups.Checked;
@@ -606,7 +609,7 @@ namespace KeePass.Forms
 						bool bParseSuccess;
 						pe.ExpiryTime = ParseDateTime(ref strField, cfi, dtNow,
 							out bParseSuccess);
-						pe.Expires = (bParseSuccess && (pe.ExpiryTime != dtNoExpire));
+						pe.Expires = (bParseSuccess && (pe.ExpiryTime != dtNeverExpires));
 					}
 					else if(cfi.Type == CsvFieldType.Tags)
 						StrUtil.AddTags(pe.Tags, StrUtil.StringToTags(strField));
