@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ using KeePass.Util.Spr;
 using KeePassLib;
 using KeePassLib.Collections;
 using KeePassLib.Cryptography.PasswordGenerator;
+using KeePassLib.Delegates;
 using KeePassLib.Interfaces;
 using KeePassLib.Security;
 using KeePassLib.Serialization;
@@ -71,6 +72,7 @@ namespace KeePass.Forms
 		private bool m_bBlockColumnUpdates = false;
 		private uint m_uBlockGroupSelectionEvent = 0;
 		private uint m_uBlockEntrySelectionEvent = 0;
+		private uint m_uBlockEntrySelectionRestoration = 0;
 
 		private bool m_bForceExitOnce = false;
 
@@ -185,8 +187,6 @@ namespace KeePass.Forms
 			m_nLockTimerMax = (int)Program.Config.Security.WorkspaceLocking.LockAfterTime;
 			m_nClipClearMax = Program.Config.Security.ClipboardClearAfterSeconds;
 
-			NativeLib.AllowNative = Program.Config.Native.NativeKeyTransformations;
-
 			m_ctxEntryPreviewContextMenu.Attach(m_richEntryView, this);
 
 			m_dynStringsMenu = new DynamicMenu(m_menuEntryOtherData.DropDownItems);
@@ -292,7 +292,13 @@ namespace KeePass.Forms
 			CopyMenuItemText(m_tbViewsShowAll, m_menuFindAll, null);
 			CopyMenuItemText(m_tbViewsShowExpired, m_menuFindExp, null);
 
-			UIUtil.EnableAutoCompletion(m_tbQuickFind, false);
+			// UIUtil.EnableAutoCompletion(m_tbQuickFind, false); // KPB 2349
+			UIUtil.SetCueBanner(m_tbQuickFind, (WinUtil.IsAtLeastWindowsVista ?
+				string.Empty : " ") + KPRes.Search);
+			m_cmbQuickFind = m_tbQuickFind.ComboBox;
+			if(m_cmbQuickFind != null)
+				m_cmbQuickFind.SelectionChangeCommitted += this.OnQuickFindSelectionChangeCommitted;
+			else { Debug.Assert(false); }
 
 			bool bVisible = Program.Config.MainWindow.ToolBar.Show;
 			m_toolMain.Visible = bVisible;
@@ -354,6 +360,7 @@ namespace KeePass.Forms
 			ctxHeader.Items.Add(tsmiCfgCol);
 			m_lvEntries.HeaderContextMenuStrip = ctxHeader;
 
+			m_lvEntries.SupportSelectAll = false;
 			m_lvEntries.UseAlternatingItemStyles = true;
 
 			m_pListSorter = Program.Config.MainWindow.ListSorting;
@@ -421,10 +428,6 @@ namespace KeePass.Forms
 			}
 			catch(Exception) { Debug.Assert(false); }
 
-			string strSearchTr = ((WinUtil.IsAtLeastWindowsVista ?
-				string.Empty : " ") + KPRes.Search);
-			UIUtil.SetCueBanner(m_tbQuickFind, strSearchTr);
-
 #if DEBUG
 			Program.Config.CustomConfig.SetBool("TestItem1", true);
 			Program.Config.CustomConfig.SetULong("TestItem2", 13);
@@ -480,6 +483,17 @@ namespace KeePass.Forms
 
 			LoadPlugins();
 
+			GAction<ContextMenuStrip, ToolStripMenuItem> fAddMore = ((ctx, tsmi) =>
+			{
+				ctx.Items.AddRange(new ToolStripItem[] {
+					new ToolStripSeparator(),
+					new ToolStripMenuItem(KPRes.MoreCommands,
+						Properties.Resources.B16x16_Redo,
+						((senderMC, eMC) => { tsmi.ShowDropDown(); })) });
+			});
+			fAddMore(m_ctxGroupList, m_menuGroup);
+			fAddMore(m_ctxPwList, m_menuEntry);
+
 			bool bCanMaximize = ((this.WindowState == FormWindowState.Normal) && !IsTrayed());
 			Debug.Assert(bCanMaximize);
 			if(bMaximize && bCanMaximize)
@@ -628,30 +642,21 @@ namespace KeePass.Forms
 			pd.RootGroup.AddGroup(pg, true);
 
 			PwEntry pe = new PwEntry(true, true);
-			pe.Strings.Set(PwDefs.TitleField, new ProtectedString(pd.MemoryProtection.ProtectTitle,
-				KPRes.SampleEntry));
-			pe.Strings.Set(PwDefs.UserNameField, new ProtectedString(pd.MemoryProtection.ProtectUserName,
-				KPRes.UserName));
-			pe.Strings.Set(PwDefs.UrlField, new ProtectedString(pd.MemoryProtection.ProtectUrl,
-				PwDefs.HomepageUrl));
-			pe.Strings.Set(PwDefs.PasswordField, new ProtectedString(pd.MemoryProtection.ProtectPassword,
-				KPRes.Password));
-			pe.Strings.Set(PwDefs.NotesField, new ProtectedString(pd.MemoryProtection.ProtectNotes,
-				KPRes.Notes));
+			ImportUtil.Add(pe, PwDefs.TitleField, KPRes.SampleEntry, pd);
+			ImportUtil.Add(pe, PwDefs.UserNameField, KPRes.UserName, pd);
+			ImportUtil.Add(pe, PwDefs.PasswordField, KPRes.Password, pd);
+			ImportUtil.Add(pe, PwDefs.UrlField, PwDefs.HomepageUrl, pd);
+			ImportUtil.Add(pe, PwDefs.NotesField, KPRes.Notes, pd);
 			pe.AutoType.Add(new AutoTypeAssociation(KPRes.TargetWindow,
 				@"{USERNAME}{TAB}{PASSWORD}{TAB}{ENTER}"));
 			// for(int i = 0; i < 30; ++i) pe.CustomData.Set("Test" + i.ToString("D2"), "12345");
 			pd.RootGroup.AddEntry(pe, true);
 
 			pe = new PwEntry(true, true);
-			pe.Strings.Set(PwDefs.TitleField, new ProtectedString(pd.MemoryProtection.ProtectTitle,
-				KPRes.SampleEntry + " #2"));
-			pe.Strings.Set(PwDefs.UserNameField, new ProtectedString(pd.MemoryProtection.ProtectUserName,
-				"Michael321"));
-			pe.Strings.Set(PwDefs.UrlField, new ProtectedString(pd.MemoryProtection.ProtectUrl,
-				PwDefs.HelpUrl + "kb/testform.html"));
-			pe.Strings.Set(PwDefs.PasswordField, new ProtectedString(pd.MemoryProtection.ProtectPassword,
-				"12345"));
+			ImportUtil.Add(pe, PwDefs.TitleField, KPRes.SampleEntry + " #2", pd);
+			ImportUtil.Add(pe, PwDefs.UserNameField, "Michael321", pd);
+			ImportUtil.Add(pe, PwDefs.PasswordField, "12345", pd);
+			ImportUtil.Add(pe, PwDefs.UrlField, PwDefs.HelpUrl + "kb/testform.html", pd);
 			pe.AutoType.Add(new AutoTypeAssociation("*Test Form - KeePass*", string.Empty));
 			pd.RootGroup.AddEntry(pe, true);
 
@@ -666,26 +671,17 @@ namespace KeePass.Forms
 			prf.GeneratorType = PasswordGeneratorType.CharSet;
 			for(uint iSamples = 0; iSamples < 1500; ++iSamples)
 			{
-				pg = pd.RootGroup.Groups.GetAt(iSamples % 5);
-
 				pe = new PwEntry(true, true);
+				pd.RootGroup.Groups.GetAt(iSamples % 5).AddEntry(pe, true);
 
-				ProtectedString ps;
-				PwGenerator.Generate(out ps, prf, null, null);
-				pe.Strings.Set(PwDefs.TitleField, ps.WithProtection(
-					pd.MemoryProtection.ProtectTitle));
-				PwGenerator.Generate(out ps, prf, null, null);
-				pe.Strings.Set(PwDefs.UserNameField, ps.WithProtection(
-					pd.MemoryProtection.ProtectUserName));
-				PwGenerator.Generate(out ps, prf, null, null);
-				pe.Strings.Set(PwDefs.UrlField, ps.WithProtection(
-					pd.MemoryProtection.ProtectUrl));
-				PwGenerator.Generate(out ps, prf, null, null);
-				pe.Strings.Set(PwDefs.PasswordField, ps.WithProtection(
-					pd.MemoryProtection.ProtectPassword));
-				PwGenerator.Generate(out ps, prf, null, null);
-				pe.Strings.Set(PwDefs.NotesField, ps.WithProtection(
-					pd.MemoryProtection.ProtectNotes));
+				pe.IconId = (PwIcon)r.Next(0, (int)PwIcon.Count);
+
+				foreach(string strName in PwDefs.GetStandardFields())
+				{
+					ProtectedString ps;
+					PwGenerator.Generate(out ps, prf, null, null);
+					ImportUtil.Add(pe, strName, ps.ReadString(), pd);
+				}
 
 				pe.CreationTime = DateTime.FromBinary(lTimeMin + (long)(r.NextDouble() *
 					(lTimeMax - lTimeMin)));
@@ -697,10 +693,6 @@ namespace KeePass.Forms
 					(lTimeMax - lTimeMin)));
 				pe.LocationChanged = DateTime.FromBinary(lTimeMin + (long)(r.NextDouble() *
 					(lTimeMax - lTimeMin)));
-
-				pe.IconId = (PwIcon)r.Next(0, (int)PwIcon.Count);
-
-				pg.AddEntry(pe, true);
 			}
 
 			pd.CustomData.Set("Sample Custom Data 1", "0123456789", null);
@@ -988,10 +980,7 @@ namespace KeePass.Forms
 		private void OnEntrySelectAll(object sender, EventArgs e)
 		{
 			++m_uBlockEntrySelectionEvent;
-			foreach(ListViewItem lvi in m_lvEntries.Items)
-			{
-				lvi.Selected = true;
-			}
+			UIUtil.SelectAllItems(m_lvEntries);
 			--m_uBlockEntrySelectionEvent;
 
 			ResetDefaultFocus(m_lvEntries);
@@ -1002,19 +991,19 @@ namespace KeePass.Forms
 		{
 			if(UIIsInteractionBlocked()) { e.Cancel = true; return; }
 
+			bool bSystem = ((e.CloseReason == CloseReason.TaskManagerClosing) ||
+				(e.CloseReason == CloseReason.WindowsShutDown));
+			if(bSystem) SaveConfig();
+
 			if(!m_bForceExitOnce) // If not executed by 'File' -> 'Exit'
 			{
-				if((e.CloseReason != CloseReason.TaskManagerClosing) &&
-					(e.CloseReason != CloseReason.WindowsShutDown))
+				if(Program.Config.MainWindow.CloseButtonMinimizesWindow && !bSystem)
 				{
-					if(Program.Config.MainWindow.CloseButtonMinimizesWindow)
-					{
-						SaveWindowPositionAndSize();
+					SaveWindowPositionAndSize();
 
-						e.Cancel = true;
-						UIUtil.SetWindowState(this, FormWindowState.Minimized);
-						return;
-					}
+					e.Cancel = true;
+					UIUtil.SetWindowState(this, FormWindowState.Minimized);
+					return;
 				}
 			}
 			m_bForceExitOnce = false; // Reset (flag works once only)
@@ -1032,9 +1021,7 @@ namespace KeePass.Forms
 			// When shutting down, it can happen that only OnFormClosing
 			// is called without the form actually being closed afterwards,
 			// thus we must update the UI in this case now
-			if((e.CloseReason == CloseReason.TaskManagerClosing) ||
-				(e.CloseReason == CloseReason.WindowsShutDown))
-				UpdateUI(true, null, true, null, true, null, false);
+			if(bSystem) UpdateUI(true, null, true, null, true, null, false);
 		}
 
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
@@ -1106,7 +1093,7 @@ namespace KeePass.Forms
 			UIUtil.SetChecked(m_menuViewShowToolBar, b);
 		}
 
-		private void OnViewShowEntryView(object sender, EventArgs e)
+		private void OnViewShowDetailsView(object sender, EventArgs e)
 		{
 			Debug.Assert(m_bFormLoaded); // The following toggles!
 			ShowEntryView(!Program.Config.MainWindow.EntryView.Show);
@@ -1171,57 +1158,13 @@ namespace KeePass.Forms
 			}
 		}
 
-		private void OnQuickFindSelectedIndexChanged(object sender, EventArgs e)
+		private void OnQuickFindSelectionChangeCommitted(object sender, EventArgs e)
 		{
-			if(m_uBlockQuickFind != 0) return;
-			++m_uBlockQuickFind;
+			if(!m_tbQuickFind.DroppedDown) return; // Allow selecting every item
 
-			string strSearch = m_tbQuickFind.Text; // Text, not selected index!
-
-			lock(m_objQuickFindSync)
-			{
-				int iNow = Environment.TickCount;
-				if(((iNow - m_iLastQuickFindTicks) <= 1000) &&
-					(strSearch == m_strLastQuickSearch))
-				{
-					--m_uBlockQuickFind;
-					return;
-				}
-
-				m_iLastQuickFindTicks = iNow;
-				m_strLastQuickSearch = strSearch;
-			}
-
-			// Lookup in combobox for the current search
-			int nExistsAlready = -1;
-			for(int i = 0; i < m_tbQuickFind.Items.Count; ++i)
-			{
-				string strItemText = (string)m_tbQuickFind.Items[i];
-				if(strItemText.Equals(strSearch, StrUtil.CaseIgnoreCmp))
-				{
-					nExistsAlready = i;
-					break;
-				}
-			}
-
-			// Update the history items in the combobox
-			if(nExistsAlready >= 0)
-				m_tbQuickFind.Items.RemoveAt(nExistsAlready);
-			else if(m_tbQuickFind.Items.Count >= 8)
-				m_tbQuickFind.Items.RemoveAt(m_tbQuickFind.Items.Count - 1);
-
-			m_tbQuickFind.Items.Insert(0, strSearch);
-
-			// if(bDoSetText) m_tbQuickFind.Text = strSearch;
-			m_tbQuickFind.SelectedIndex = 0;
-			m_tbQuickFind.Select(0, strSearch.Length);
-
-			// Asynchronous invocation allows to cleanly process
-			// an Enter keypress before blocking the UI
-			BeginInvoke(new PerformSearchQuickDelegate(this.PerformSearchQuick),
-				strSearch, false, true);
-
-			--m_uBlockQuickFind;
+			string str = (m_tbQuickFind.SelectedItem as string);
+			if(!string.IsNullOrEmpty(str)) PerformSearchQuickAsync(str);
+			else { Debug.Assert(false); }
 		}
 
 		private void OnQuickFindKeyDown(object sender, KeyEventArgs e)
@@ -1229,7 +1172,7 @@ namespace KeePass.Forms
 			if(e.KeyCode == Keys.Return) // Return == Enter
 			{
 				UIUtil.SetHandled(e, true);
-				OnQuickFindSelectedIndexChanged(sender, e);
+				PerformSearchQuickAsync(m_tbQuickFind.Text);
 			}
 		}
 
@@ -1271,7 +1214,7 @@ namespace KeePass.Forms
 
 				GlobalWindowManager.CustomizeFormHandleCreated(this, null, true);
 
-				AppConfigSerializer.Save();
+				SaveConfig();
 				UpdateTrayIcon(true);
 			}
 			UIUtil.DestroyForm(ofDlg);
@@ -1702,7 +1645,7 @@ namespace KeePass.Forms
 			{
 				PwIcon pi = (PwIcon)ipf.ChosenIconId;
 				PwUuid pu = ipf.ChosenCustomIconUuid;
-				bool bCustom = !pu.Equals(PwUuid.Zero);
+				bool bCustom = !pu.IsZero;
 
 				foreach(PwEntry pe in vEntries)
 				{
@@ -1794,17 +1737,17 @@ namespace KeePass.Forms
 
 		private void OnToolsPwGenerator(object sender, EventArgs e)
 		{
-			PwDatabase pwDb = m_docMgr.ActiveDatabase;
+			PwDatabase pd = m_docMgr.ActiveDatabase;
 
 			PwGeneratorForm pgf = new PwGeneratorForm();
-			pgf.InitEx(null, pwDb.IsOpen, IsTrayed());
+			pgf.InitEx(null, pd.IsOpen, IsTrayed());
 
 			if(pgf.ShowDialog() == DialogResult.OK)
 			{
-				if(pwDb.IsOpen)
+				if(pd.IsOpen)
 				{
 					PwGroup pg = GetSelectedGroup();
-					if(pg == null) pg = pwDb.RootGroup;
+					if(pg == null) pg = pd.RootGroup;
 
 					PwEntry pe = new PwEntry(true, true);
 					pg.AddEntry(pe, true);
@@ -1814,13 +1757,13 @@ namespace KeePass.Forms
 					bool bAcceptAlways = false;
 					string strError;
 					ProtectedString psNew = PwGeneratorUtil.GenerateAcceptable(
-						pgf.SelectedProfile, pbAdditionalEntropy, pe, pwDb,
-						true, ref bAcceptAlways, out strError);
+						pgf.SelectedProfile, pbAdditionalEntropy, pe, pd, true,
+						ref bAcceptAlways, out strError);
 
 					if(string.IsNullOrEmpty(strError))
 					{
 						pe.Strings.Set(PwDefs.PasswordField, psNew.WithProtection(
-							pwDb.MemoryProtection.ProtectPassword));
+							pd.MemoryProtection.ProtectPassword));
 
 						UpdateUI(false, null, false, null, true, null, true, m_lvEntries);
 						SelectEntry(pe, true, true, true, true);
@@ -1833,14 +1776,14 @@ namespace KeePass.Forms
 
 		private void OnToolsTanWizard(object sender, EventArgs e)
 		{
-			PwDatabase pwDb = m_docMgr.ActiveDatabase;
-			if(!pwDb.IsOpen) { Debug.Assert(false); return; }
+			PwDatabase pd = m_docMgr.ActiveDatabase;
+			if(!pd.IsOpen) { Debug.Assert(false); return; }
 
 			PwGroup pgSelected = GetSelectedGroup();
 			if(pgSelected == null) return;
 
 			TanWizardForm twf = new TanWizardForm();
-			twf.InitEx(pwDb, pgSelected);
+			twf.InitEx(pd, pgSelected);
 
 			if(UIUtil.ShowDialogAndDestroy(twf) == DialogResult.OK)
 				UpdateUI(false, null, false, null, true, null, true);
@@ -1880,7 +1823,7 @@ namespace KeePass.Forms
 			if((pe != null) && (pe.ParentGroup != null) &&
 				(pe.ParentGroup.Name == strLink))
 			{
-				ShowSelectedEntryParentGroup();
+				ShowParentGroup(pe);
 				ResetDefaultFocus(m_lvEntries);
 			}
 			else if(strEntryUrl == strLink)
@@ -1996,8 +1939,8 @@ namespace KeePass.Forms
 
 		private void OnToolsGeneratePasswordList(object sender, EventArgs e)
 		{
-			PwDatabase pwDb = m_docMgr.ActiveDatabase;
-			if(!pwDb.IsOpen) return;
+			PwDatabase pd = m_docMgr.ActiveDatabase;
+			if(!pd.IsOpen) return;
 
 			PwGeneratorForm pgf = new PwGeneratorForm();
 			pgf.InitEx(null, true, IsTrayed());
@@ -2005,7 +1948,7 @@ namespace KeePass.Forms
 			if(pgf.ShowDialog() == DialogResult.OK)
 			{
 				PwGroup pg = GetSelectedGroup();
-				if(pg == null) pg = pwDb.RootGroup;
+				if(pg == null) pg = pd.RootGroup;
 
 				SingleLineEditForm dlgCount = new SingleLineEditForm();
 				dlgCount.InitEx(KPRes.GenerateCount, KPRes.GenerateCountDesc,
@@ -2029,8 +1972,8 @@ namespace KeePass.Forms
 
 						string strError;
 						ProtectedString psNew = PwGeneratorUtil.GenerateAcceptable(
-							pgf.SelectedProfile, pbAdditionalEntropy, pe, pwDb,
-							true, ref bAcceptAlways, out strError);
+							pgf.SelectedProfile, pbAdditionalEntropy, pe, pd, true,
+							ref bAcceptAlways, out strError);
 
 						if(!string.IsNullOrEmpty(strError))
 						{
@@ -2039,7 +1982,7 @@ namespace KeePass.Forms
 						}
 
 						pe.Strings.Set(PwDefs.PasswordField, psNew.WithProtection(
-							pwDb.MemoryProtection.ProtectPassword));
+							pd.MemoryProtection.ProtectPassword));
 
 						l.Add(pe);
 					}
@@ -2511,7 +2454,7 @@ namespace KeePass.Forms
 
 		private void OnFindParentGroup(object sender, EventArgs e)
 		{
-			ShowSelectedEntryParentGroup();
+			ShowParentGroup(null);
 		}
 
 		private void OnFindLastMod(object sender, EventArgs e)
