@@ -196,11 +196,6 @@ namespace KeePass.Native
 		// [return: MarshalAs(UnmanagedType.Bool)]
 		// private static extern bool GetKeyboardState(IntPtr lpKeyState);
 
-		// [DllImport("User32.dll", CharSet = CharSet.Auto)]
-		// [return: MarshalAs(UnmanagedType.Bool)]
-		// private static extern bool GetKeyboardLayoutName([MarshalAs(UnmanagedType.LPTStr)]
-		//	StringBuilder pwszKLID);
-
 		[DllImport("User32.dll")]
 		internal static extern ushort GetKeyState(int vKey);
 
@@ -399,6 +394,11 @@ namespace KeePass.Native
 		[DllImport("User32.dll")]
 		internal static extern IntPtr GetKeyboardLayout(uint idThread);
 
+		[DllImport("User32.dll", CharSet = CharSet.Auto)]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		private static extern bool GetKeyboardLayoutName(
+			[MarshalAs(UnmanagedType.LPTStr)] StringBuilder pszKLID);
+
 		[DllImport("User32.dll")]
 		internal static extern IntPtr ActivateKeyboardLayout(IntPtr hkl, uint uFlags);
 
