@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ using System.Text;
 using System.Windows.Forms;
 
 using KeePassLib.Native;
+using KeePassLib.Utility;
 
 namespace KeePass.UI
 {
@@ -98,9 +99,7 @@ namespace KeePass.UI
 			if((m_vImages != null) && (nIdx >= 0) && (nIdx < m_vImages.Count) &&
 				(m_vImages[nIdx] != null))
 			{
-				g.InterpolationMode = InterpolationMode.HighQualityBicubic;
-				g.SmoothingMode = SmoothingMode.HighQuality;
-
+				GfxUtil.SetHighQuality(g);
 				g.DrawImage(m_vImages[nIdx], rectImg);
 			}
 
