@@ -756,6 +756,12 @@ namespace KeePassLib.Utility
 #endif
 		}
 
+		internal static bool TryParseDoubleInvariant(string str, out double d)
+		{
+			return double.TryParse(str, NumberStyles.Float,
+				NumberFormatInfo.InvariantInfo, out d);
+		}
+
 		public static bool TryParseDateTime(string str, out DateTime dt)
 		{
 #if !KeePassLibSD
@@ -967,7 +973,8 @@ namespace KeePassLib.Utility
 					if((strPartX.Length <= 19) && (strPartY.Length <= 19))
 					{
 						ulong uX, uY;
-						if(ulong.TryParse(strPartX, out uX) && ulong.TryParse(strPartY, out uY))
+						if(TryParseULongInvariant(strPartX, out uX) &&
+							TryParseULongInvariant(strPartY, out uY))
 						{
 							if(uX < uY) return -1;
 							if(uX > uY) return 1;
@@ -979,7 +986,8 @@ namespace KeePassLib.Utility
 					else
 					{
 						double dX, dY;
-						if(double.TryParse(strPartX, out dX) && double.TryParse(strPartY, out dY))
+						if(TryParseDoubleInvariant(strPartX, out dX) &&
+							TryParseDoubleInvariant(strPartY, out dY))
 						{
 							if(dX < dY) return -1;
 							if(dX > dY) return 1;
@@ -1124,6 +1132,30 @@ namespace KeePassLib.Utility
 			return true;
 		}
 
+		// Cf. MemUtil.ParseBase32.
+		internal static bool IsBase32String(string str)
+		{
+			if(str == null) throw new ArgumentNullException("str");
+
+			bool bPadding = false;
+
+			for(int i = 0; i < str.Length; ++i)
+			{
+				char ch = str[i];
+
+				if(ch == '=') { bPadding = true; continue; }
+				if(bPadding) return false;
+
+				if((ch >= 'A') && (ch <= 'Z')) continue;
+				if((ch >= 'a') && (ch <= 'z')) continue;
+				if((ch >= '2') && (ch <= '7')) continue;
+
+				return false;
+			}
+
+			return true;
+		}
+
 #if !KeePassLibSD
 		private static readonly char[] g_vPatternPartsSep = new char[] { '*' };
 		public static bool SimplePatternMatch(string strPattern, string strText,
@@ -1535,13 +1567,11 @@ namespace KeePassLib.Utility
 			if(lTags.Count >= 2)
 			{
 				// Deduplicate
-				Dictionary<string, bool> d = new Dictionary<string, bool>();
-				for(int i = lTags.Count - 1; i >= 0; --i)
-					d[lTags[i]] = true;
-				if(d.Count != lTags.Count)
+				HashSet<string> hs = new HashSet<string>(lTags);
+				if(hs.Count != lTags.Count)
 				{
 					lTags.Clear();
-					lTags.AddRange(d.Keys);
+					lTags.AddRange(hs);
 				}
 
 				lTags.Sort(StrUtil.CompareNaturally);
@@ -1643,13 +1673,13 @@ namespace KeePassLib.Utility
 		}
 
 		/// <summary>
-		/// Split a string and include the separators in the splitted array.
+		/// Split a string and include the separators in the split array.
 		/// </summary>
 		/// <param name="str">String to split.</param>
 		/// <param name="vSeps">Separators.</param>
 		/// <param name="bCaseSensitive">Specifies whether separators are
 		/// matched case-sensitively or not.</param>
-		/// <returns>Splitted string including separators.</returns>
+		/// <returns>Split string including separators.</returns>
 		public static List<string> SplitWithSep(string str, string[] vSeps,
 			bool bCaseSensitive)
 		{
@@ -1699,6 +1729,14 @@ namespace KeePassLib.Utility
 			return str;
 		}
 
+		private static readonly char[] g_vNewLine = new char[] { '\r', '\n' };
+		internal static bool IsMultiLine(string str)
+		{
+			if(str == null) { Debug.Assert(false); return false; }
+
+			return (str.IndexOfAny(g_vNewLine) >= 0);
+		}
+
 		public static List<string> SplitSearchTerms(string strSearch)
 		{
 			List<string> l = new List<string>();
@@ -2158,5 +2196,23 @@ namespace KeePassLib.Utility
 
 			return (iB == cB);
 		}
+
+		internal static byte[] GetBytesSZ(string str, Encoding enc)
+		{
+			if(enc == null) throw new ArgumentNullException("enc");
+
+			int cbNull;
+			if(enc is UTF8Encoding) cbNull = 1;
+			else if(enc is UnicodeEncoding) cbNull = 2;
+			else throw new ArgumentOutOfRangeException("enc");
+
+			Debug.Assert(str != null);
+			if(string.IsNullOrEmpty(str)) return new byte[cbNull];
+
+			int cb = enc.GetByteCount(str);
+			byte[] pb = new byte[cb + cbNull];
+			enc.GetBytes(str, 0, str.Length, pb, 0);
+			return pb;
+		}
 	}
 }
